/****************************************************************************\
  FILE..........: akm_defs.h
  AUTHOR........: bsm
  COPYRIGHT.....: Copyright(c) 2004
  VERSION.......: 1.00
  DESCRIPTION...: The module conatains definition of 

  HISTORY.......: DATE     COMMENT
                  -------- ------------------------------------------------
                  26-10-04 Created.
\****************************************************************************/

/*===========================================[ REDEFINITION DEFENCE ]=======*/
#ifndef AKM_DEFS_H
#define AKM_DEFS_H

/*===========================================[ SPECIAL ]====================*/
/*===========================================[ IMPORT DECLARATIONS ]========*/
/*===========================================[ PUBLIC CONSTANTS ]===========*/

/*
 * Severity codes for akmLogoutText()
 */
#define SEVERITY_INFO       0
#define SEVERITY_WARNING    1
#define SEVERITY_ERROR      2


/*
 * Infinite timeout for akmSleep()
 */
#define TIMEOUT_INFINITE    0xFFFFFFFF


/*
 * akmShowWindow() Commands
 */
#define SW_HIDE             0
#define SW_SHOWNORMAL       1
#define SW_NORMAL           1
#define SW_SHOWMINIMIZED    2
#define SW_SHOWMAXIMIZED    3
#define SW_MAXIMIZE         3
#define SW_SHOWNOACTIVATE   4
#define SW_SHOW             5
#define SW_MINIMIZE         6
#define SW_SHOWMINNOACTIVE  7
#define SW_SHOWNA           8
#define SW_RESTORE          9
#define SW_SHOWDEFAULT      10
#define SW_FORCEMINIMIZE    11
// AKM specific
#define SW_AKM_ENSURE_ONSCREEN  10001
#define SW_AKM_CENTER_ONSCREEN  10002

/*
 * AKM system window names for akmShowWindow()
 */
#define AKM_STATUS_BAR_NAME  "__STATUS_BAR___/\\/\\/\\"
#define AKM_TOOL_BAR_NAME    "__TOOL_BAR___/\\/\\/\\"
#define AKM_VIEW_BAR_NAME    "__VIEW_BAR___/\\/\\/\\"
#define AKM_OUTPUT_BAR_NAME  "__OUTPUT_BAR___/\\/\\/\\"
#define AKM_HELP_BAR_NAME    "__HELP_BAR___/\\/\\/\\"
#define AKM_PCODE_WND_NAME   "__PCODE_WND___/\\/\\/\\"


/*
 * stdMessageBox() mode values
 */
// To indicate the buttons displayed in the message box, specify one of the following values
#define MB_OK                       0x00000000L
#define MB_OKCANCEL                 0x00000001L
#define MB_ABORTRETRYIGNORE         0x00000002L
#define MB_YESNOCANCEL              0x00000003L
#define MB_YESNO                    0x00000004L
#define MB_RETRYCANCEL              0x00000005L

// To display an icon in the message box, specify one of the following values
#define MB_ICONERROR                0x00000010L
#define MB_ICONQUESTION             0x00000020L
#define MB_ICONWARNING              0x00000030L
#define MB_ICONINFORMATION          0x00000040L

#define MB_ICONHAND                 0x00000010L
#define MB_ICONQUESTION             0x00000020L
#define MB_ICONEXCLAMATION          0x00000030L
#define MB_ICONASTERISK             0x00000040L

// To indicate the default button, specify one of the following values
#define MB_DEFBUTTON1               0x00000000L
#define MB_DEFBUTTON2               0x00000100L
#define MB_DEFBUTTON3               0x00000200L
#define MB_DEFBUTTON4               0x00000300L

// To indicate the modality of the dialog box, specify one of the following values
#define MB_APPLMODAL                0x00000000L
#define MB_SYSTEMMODAL              0x00001000L
#define MB_TASKMODAL                0x00002000L
#define MB_HELP                     0x00004000L // Help Button

// Message Box appearance
#define MB_NOFOCUS                  0x00008000L
#define MB_SETFOREGROUND            0x00010000L
#define MB_DEFAULT_DESKTOP_ONLY     0x00020000L
#define MB_TOPMOST                  0x00040000L
#define MB_RIGHT                    0x00080000L
#define MB_RTLREADING               0x00100000L

// Return Values
#define IDOK                1
#define IDCANCEL            2
#define IDABORT             3
#define IDRETRY             4
#define IDIGNORE            5
#define IDYES               6
#define IDNO                7
#define IDCLOSE             8
#define IDHELP              9


/*
 * Values for PrjTabMode in akmShowPrjTab()
 */
#define PRJTAB_HIDE      0  // hides project tab window
#define PRJTAB_SHOW      1  // show project tab window without changing active tab
#define PRJTAB_AMODEL    2  // show project tab window and activate model tab
#define PRJTAB_AWINDOW   3  // show project tab window and activate window-template tab
#define PRJTAB_AOSCILL   4  // show project tab window and activate oscill tab
#define PRJTAB_ADATA     5  // show project tab window and activate data tab
#define PRJTAB_APCODE    6  // show project tab window and activate p-code tab


/*
 * Default model name. Model index's start from 1 so first (but not 
 * necessarily active) model is model with index 1
 */
#define MODEL_DEFNAME    "1"


/*
 * akmGetModelConnStatus() return Codes
 */
#define MDLCONN_OFFLINE            0
#define MDLCONN_ONLINE             1
#define MDLCONN_ONLINE_PAUSED      2
#define MDLCONN_CONNECTING         3


/*
 * Values for DataSourceName in akmModelConnectDataSrc()
 */
#define DATASRC_CURRENT      ""        // special name that indicate current data source
#define DATASRC_KWP          "KWP_RS"  //  KWP2000   RS232
#define DATASRC_CCP          "CCP_USB" //  CCP v2.1   USB
#define DATASRC_LOGGER_KWP   "Logger_KWP" //  KWP2000   LOGGER
#define DATASRC_LOGGER_CCP   "Logger_CCP" //  CCP   LOGGER
#define DATASRC_KWP_CAN      "KWP_CAN" //  KWP2000  CAN-
#define DATASRC_KWP_LAN      "KWP_LAN" //  KWP2000   COMM-over-LAN
#define DATASRC_KWP_REMOTE   "Remote_KWP" //  KWP2000   COMM-over-IP

/*
 * Values for 'iUIType' in akmModelConnectDataSrc()
 */
#define DATASRC_WAIT_USER       0  //      
#define DATASRC_DEFAULT_ACTION  1  //    ,   ESC 


/*
 * Value codes for akmGetModelConnIsPaused() / akmSetModelConnPaused()
 */
#define MDLCONN_PAUSED            0
#define MDLCONN_NOTPAUSED         1


/*
 * Definitions for paramID
 */
#define AKM_PARAM_MIN_ID         0x00000001
#define AKM_PARAM_MAX_ID         0x0000EFFF
#define AKM_GROUP_MIN_ID         0x00010000
#define AKM_GROUP_MAX_ID         0x0EFF0000
#define AKM_MODEL_MIN_ID         0x10000000
#define AKM_MODEL_MAX_ID         0xE0000000

#define AKM_PARAM_INVALID_ID    -1
#define AKM_NO_INPUT_QUANTITY   -2

#define AKM_GROUP_INVALID_ID    -1
#define AKM_GROUP_ROOT_ID       -2

#define AKM_PARAM_MASK           0x0000FFFF
#define AKM_GROUP_MASK           0x0FFF0000
#define AKM_MODEL_MASK           0xF0000000


/*
 * Maximum data-array size for akmGetParamIntDescr()
 */
#define PARAM_INTDESCR_ARRAY_SIZE  30

/*
 * Fields meaning in data-array returned by akmGetParamIntDescr()
 */
#define P_LOCATION       0  // STATIC or DYNAMIC
#define P_INTERPRET      1  // BIT, COMPLEX_0, COMPLEX_1, COMPLEX_2, COMPLEX_3 or STRING
#define P_SCALARTYPE     2  // SBYTE, UBYTE, SWORD, UWORD, SLONG, ULONG, FLOAT or DOUBLE
#define P_ID             3  // fully temporary ID
#define P_DATAID         4  // fixed ID for use in data sources (now only in KWP as ParamID)
#define P_ISGRID         5  // 0 or 1
#define P_ISVIRTUAL      6  // 0 or 1
#define P_ISFORMULA      7  // 0 or 1
#define P_DIMENTION1     8  // for the COMPLEX_1 it is the size of the COMPLEX_1 vector
#define P_DIMENTION2     9  // for the COMPLEX_2 it is the columns count of the COMPLEX_2 matrix
#define P_DIMENTION3     10 // used for COMPLEX_3
#define P_ALLOWCONTROL   11 // 0 or 1
#define P_DIRECTCTRLADDR 12 // address of DirectCtrl_key byte
#define P_GRIDBASE       13 // used if COMPLEX_1
#define P_BITBASE        14 // used if BIT
#define P_BITMASK        15 // used if BIT
#define P_ADDRESS        16
#define P_MEMSEGADDR     17
#define P_BYTEORDER      18 // MSB_NONE, MSB_FIRST or MSB_LAST
#define P_REFRESHUNIT    19 // indexes possible scale unit, -1 means unused
#define P_STRUCTACCESSLV 20 // LEVEL_0, LEVEL_1 or LEVEL_2
#define P_DATAACCESSLV   21 // LEVEL_0, LEVEL_1 or LEVEL_2
#define P_CRCTYPE        22 // CRC16, CRC32 or CRC_NONE
#define P_CRCSTART       23
#define P_CRCSIZE        24

/*
 * Value meaning for P_LOCATION field in akmGetParamIntDescr()
 */
#define PL_STATIC        0
#define PL_DYNAMIC       1

/*
 * Value meaning for P_INTERPRET field in akmGetParamIntDescr()
 */
#define PI_BIT           0
#define PI_COMPLEX_0     1
#define PI_COMPLEX_1     2
#define PI_COMPLEX_2     3
#define PI_COMPLEX_3     4
#define PI_STRING        5

/*
 * Value meaning for P_SCALARTYPE field in akmGetParamIntDescr()
 */
#define PS_SBYTE         0
#define PS_UBYTE         1
#define PS_SWORD         2
#define PS_UWORD         3
#define PS_SLONG         4
#define PS_ULONG         5
#define PS_FLOAT         6
#define PS_DOUBLE        7


/*
 * Maximum data-array size for akmGetParamFloatDescr()
 */
#define PARAM_FLOATDESCR_ARRAY_SIZE  10

/*
 * Fields meaning in data-array returned by akmGetParamFloatDescr()
 */
#define PF_MINRANGE      0  // data min-max ranges
#define PF_MAXRANGE      1  // data min-max ranges
#define PF_REFRESHRATE   2  // max refresh rate in 'scale units'


/*
 * Maximum data-array size for akmGetParamData()
 */
#define MAX_PARAMDATA_ARRAY_SIZE   100


/*
 * Values for DirectCtrlState in akmGetParamDirectCtrl() / akmSetParamDirectCtrl()
 */
#define DCTRL_OFF        0  // DirectCtrl is off
#define DCTRL_ON         1  // DirectCtrl is on
#define DCTRL_CHANGING   2  // DirectCtrl is in transient state (changing on->off or vice versa)
#define DCTRL_DISABLED  -1  // DirectCtrl is disabled (not allowed)


/*
 * Values for iMeasType in akmSetParamMeasType()
 */
#define MEAS_POLLING     0
#define MEAS_RASTER      1
#define MEAS_REQUEST     2

/*
 * Maximum paramMeas-array size for akmGetAllParamMeas()
 */
#define MAX_PARAM_MEAS_COUNT   1000

/*
 * measDef-array size for akmGetParamMeasDef()
 */
#define MEASDEF_FIELD_COUNT    3
/*
 * Fields definition for arrParamMeasDef[] in akmGetParamMeasDef()
 */
#define FMEAS_TYPE       0
#define FMEAS_PARAM      1
#define FMEAS_PARAM2     2


/*
 * Fields count for arrUserInfo[] in akmGetUsbKeyInfo()
 */
#define KEYINFO_FIELD_COUNT  5

/*
 * Fields meaning in data-array returned by akmGetUsbKeyInfo()
 */
#define KEYINFO_STATUS                    0
#define KEYINFO_PARAMSTRUCT_ACCESS_LEVEL  1
#define KEYINFO_PARAMDATA_ACCESS_LEVEL    2
#define KEYINFO_MODELSTRUCT_ACCESS_LEVEL  3
#define KEYINFO_SERIAL_NUMBER             4

/*
 * Possible KEYINFO_STATUS values
 */
#define KI_USER_ABSENT   0
#define KI_USER_LOGGED   1

/*
 * Possible *_ACCESS_LEVEL values
 */
#define KI_USER_LEVEL_0  0
#define KI_USER_LEVEL_1  1
#define KI_USER_LEVEL_2  2


/*
 * Actions for akmPerformWindowAction()
 */
#define WND_MOVESEL_DOWN  1
#define WND_MOVESEL_UP    2
#define WND_CLOSE         3


/*
 * Predefined function numbers for akmDataSrcPerformFunction()
 */
#define DATASRC_FUNC_THROTTLE_CALIBR  1
#define DATASRC_FUNC_CLEAR_SETTINGS   2
#define DATASRC_FUNC_CLEAR_DTC        3
#define DATASRC_FUNC_RESET_ECU        4
#define DATASRC_FUNC_RESET_MOTOHOURS  5
#define DATASRC_FUNC_RESET_MOTOMAX    6
#define DATASRC_FUNC_RESET_ADAPT      7


/*
 * Maximum modelCount-array size for akmGetAllModels()
 */
#define MAX_MODEL_COUNT   16


/*
 * Return codes for akmWriteHexToEcuEx()
 */
#define LOADER_EXEC_OK           1
#define LOADER_EXEC_FAIL         0
//     RESET 
#define LOADER_EXEC_NEED_RESET  -1
//   .hex-  
#define LOADER_EXEC_HEX_FAILED  -2

//  ,  RESET ,     
//   LOADER_EXEC_NEED_RESET
#define LOADER_RESET_MODE_CHECK  1
//  ,  RESET ,   ,  
//   RESET     
#define LOADER_RESET_MODE_SKIP   2
//    RESET 
#define LOADER_RESET_MODE_NORMAL 3


/*
 *      akmWriteHexToEcu2(),  'sHexName'
 */
#define HEX_DATA1 "HEX_DATA1"


/*
 * KWP- (.  akmDataSrcPerformKwpCommand())
 */
#define KWP_RDBLI     0x21
#define KWP_DDLI      0x2C
#define KWP_WDBLI     0x3B

#define KWP_CDI       0x14
#define KWP_RDTCBS    0x18

#define KWP_STC       0x81
#define KWP_SPC       0x82
#define KWP_ACP       0x83

#define KWP_RSODTC    0x17
#define KWP_FREEZE    0x12

#define KWP_STDS      0x10
#define KWP_SPDS      0x20

#define KWP_TP        0x3e

#define KWP_ER        0x11
#define KWP_REI       0x1a

#define KWP_RU        0x35
#define KWP_RD        0x34
#define KWP_TD        0x36
#define KWP_RTE       0x37

#define KWP_RFD       0x44

#define KWP_RMBA      0x23
#define KWP_WMBA      0x3D

#define KWP_SA        0x27 // Security Access

#define KWP_IOCBLI    0x30

#define KWP_STRBLI    0x31
#define KWP_SPRBLI    0x32
#define KWP_RRRBLI    0x33


/*
 * Maximum data-array size for data-source related functions
 */
#define MAX_SERVICE_DATA_SIZE    200


/*
 *       akmSaveProjectPart(),  'partToSave'
 */
#define PRJ_DATASET_PART   0x01
#define PRJ_MODEL_PART     0x02
#define PRJ_WIDNOW_PART    0x04
#define PRJ_TEMPLATE_PART  0x08
#define PRJ_PROJECT_PART   0x10


/*
 *    akmLoadArtifact(),  'artifactType'
 */
#define AKM_ARTIFACT_DATASET  0x01
#define AKM_ARTIFACT_OSCILL   0x02
#define AKM_ARTIFACT_HEX      0x03


/*
 *   *Oscill*  
 */
#define MAX_OSC_PARAM_COUNT          500
#define MAX_OSC_BUFFER_SIZE          55000

#define AKM_OSCILL_ACTIVE_NAME       ""
#define TIME_QUANT_PARAM_ID          -2
#define MAX_GEAR_DATA_COUNT          20


/*
 *   akmGraphXYWndCreate(..)
 */
#define XY_INDEX_COLOR_FONE          1
#define XY_INDEX_COLOR_PANE          2
#define XY_INDEX_COLOR_LINEH         3
#define XY_INDEX_COLOR_LINEV         4
#define XY_INDEX_COLOR_AXISH         5
#define XY_INDEX_COLOR_AXISV1        10
#define XY_INDEX_COLOR_AXISV_DATA1   11

#define XY_INDEX_STYLE_LINEH               1
#define XY_INDEX_STYLE_LINEH_WIDTH         2
#define XY_INDEX_STYLE_LINEV               3
#define XY_INDEX_STYLE_LINEV_WIDTH         4
#define XY_INDEX_STYLE_AXISH_CELL_COUNT    5
#define XY_INDEX_STYLE_AXISV_CELL_COUNT1   10
#define XY_INDEX_STYLE_AXISV_POINT_TYPE1   11
#define XY_INDEX_STYLE_AXISV_POINT_SIZE1   12

#define XY_INDEX_MIN_AXISH    0
#define XY_INDEX_MAX_AXISH    1
#define XY_INDEX_MIN_AXISV1   5
#define XY_INDEX_MAX_AXISV1   6

// Values for XY_INDEX_STYLE_AXISV_POINT_TYPEx:
// 0-none, 1-circle, 2-filled_circle, 3-square,
// 4-filled_square, 5-triangle, 6-filled_triangle, 7-dagger


/*
 *  
 */
#define PS_SOLID            0
#define PS_DASH             1       /* -------  */
#define PS_DOT              2       /* .......  */
#define PS_DASHDOT          3       /* _._._._  */
#define PS_DASHDOTDOT       4       /* _.._.._  */
#define PS_NULL             5

/*
 *   
 */
#define RGB(r,g,b)          ((r)|((g)<<8)|((b)<<16))


/*
 *  'eventType'  akmRegisterModelEvent()
 */
#define EVENT_PARAM_DATA_CHANGED     1
#define EVENT_PARAM_STRUCT_CHANGED   2


/*===========================================[ PUBLIC MACROS ]==============*/
#define MakeFullElemID(iElemID, iModelIndex) \
	(((iElemID) & (~AKM_MODEL_MASK)) | (((iModelIndex)<<28) & AKM_MODEL_MASK))

#define GetModelIndexFromID(iElemID) \
	(((iElemID)>>28)&0x0F)


/*===========================================[ RETURN CODES ]===============*/
/*===========================================[ PUBLIC TYPES ]===============*/
/*===========================================[ PUBLIC VARIABLES ]===========*/
/*===========================================[ PUBLIC FUNCTIONS ]===========*/
/*===========================================[ END REDEFINITION DEFENCE ]===*/
#endif /* AKM_DEFS_H */

/** (END OF FILE  : akm_defs.h) *********************************************/
