/****************************************************************************\
  FILE..........: plg_akm.h
  AUTHOR........: bsm
  COPYRIGHT.....: Copyright (c) 2002
  VERSION.......: 1.00
  DESCRIPTION...: The module conatains definition of

  HISTORY.......: DATE     COMMENT
                  -------- ------------------------------------------------
                  04-07-02 Created.
\****************************************************************************/

/*===========================================[ REDEFINITION DEFENCE ]=======*/
#ifndef PLG_AKM_H
#define PLG_AKM_H

/*===========================================[ IMPORT DECLARATIONS ]========*/
#include "plg_supp.h"

/*===========================================[ SPECIAL ]====================*/
#ifdef __cplusplus
	extern "C" {
#endif

/*===========================================[ VERSION ]====================*/
/*===========================================[ PUBLIC MACROS ]==============*/
/*===========================================[ PUBLIC CONSTANTS ]===========*/
#define MAX_PARAMDATA_ARRAY_SIZE     100
#define PARAM_INTDESCR_ARRAY_SIZE    30
#define PARAM_FLOATDESCR_ARRAY_SIZE  10
#define MAX_PARAM_MEAS_COUNT         1000
#define MEASDEF_FIELD_COUNT          3
#define KEYINFO_FIELD_COUNT          5
#define MAX_SERVICE_DATA_SIZE        200
#define MAX_MODEL_COUNT              16

/*===========================================[ PUBLIC TYPES ]===============*/
/*===========================================[ PUBLIC VARIABLES ]===========*/
/*===========================================[ PUBLIC FUNCTIONS ]===========*/

/*
**      
**
** 'sWindowName' specify window name or window ID in string form.
**   When window ID is specified only digits are possible.
**
** 'sWorkSpaceName' specify work space name or workspace ID in string form.
**   When workspace ID is specified only digits are possible.
**
** 'sModelName' specify model name or model ID in string form.
**   When model ID is specified only digits are possible.
**   When only one model is in project then constant 'MODEL_DEFNAME' from
**   'akm_defs.h' can be used to specify this model.
**
** 'sParamName' specify param's name or param ID in string form.
**   When param ID is specified only digits are possible.
**   Param's name may be in full format (<model_name>::<param_name> or
**   <model_ID>::<param_ID>) or in short format (<param_name> or <param_ID>).
**   When short format is specified the param is looked for only in active model.
**
*/


/*
**   'sText'    p-code.   'print'.
*/
STK_FUNC_VOID akmPrint(
	STK_PARAM_STRING sText  // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**   'sText'    AKM'2004, 
**      .    
**    P-Code.
**
** 'iSeverity' values: 
**   see 'Severity codes for akmLogoutText()' in 'akm_defs.h' header
*/
STK_FUNC_VOID akmLogoutText(
	STK_PARAM_STRING sText,     // IN
	STK_PARAM_INT    iSeverity  // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**   Win32.ShowWindow()
**
** 'iCmdShow' values:
**   see 'akmShowWindow() Commands' in 'akm_defs.h' header
** returns:
**   0  fail to process window
**   1  mode was applied to window
*/
STK_FUNC_INT akmShowWindow(
	STK_PARAM_STRING sWindowName,  // IN
	STK_PARAM_INT    iCmdShow      // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**   
**
** returns:
**   previous id of active work space
*/
STK_FUNC_INT akmSwitchToWorkSpace(
	STK_PARAM_STRING sWorkSpaceName  // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
** View or hide project window and/or select specified tab (model or data)
**
** 'iPrjTabMode' describes requested mode. Values are defined in 'akm_defs.h'
**   header
** returns:
**   previous state of project window
*/
STK_FUNC_INT akmShowPrjTab(
	STK_PARAM_INT iPrjTabMode  // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**    
**
** returns:
**   see 'akmGetModelConnStatus() return Codes' in 'akm_defs.h' header
*/
STK_FUNC_INT akmGetModelConnStatus(
	STK_PARAM_STRING sModelName  // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**        
**
** 'sDataSourceName' specifies name of data source to make connected. Note
**   that only one data source for given model at time may be active. So
**   activating one automatically deactivates other. Values are defined
**   in 'akm_defs.h' header
** 'iUIType' -     (. 'akm_defs.h'):
**             DATASRC_WAIT_USER(0) -     
**                                    
**             DATASRC_DEFAULT_ACTION(1) -    ,
**                                           ESC 
** returns:
**   0 fail to send request to connect to data source
**   1 request to connect to data source was sent
*/
STK_FUNC_INT akmModelConnectDataSrc(
	STK_PARAM_STRING sModelName,      // IN
	STK_PARAM_STRING sDataSourceName, // IN
	STK_PARAM_INT    iUIType          // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**     
**
** returns:
**   0 fail to disconnect from data source
**   1 data source was disconnected
*/
STK_FUNC_INT akmModelDisconnectDataSrc(
	STK_PARAM_STRING sModelName  // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**       
**
** returns:
**   see 'akmGetModelConnIsPaused() return Codes' in 'akm_defs.h' header
*/
STK_FUNC_INT akmGetModelConnIsPaused(
	STK_PARAM_STRING sModelName  // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**       
**
** 'iPausedState' define model's data source paused state. Values are
**   defined in 'akm_defs.h' header
** returns:
**   previous state of data source paused
*/
STK_FUNC_INT akmSetModelConnPaused(
	STK_PARAM_STRING sModelName,   // IN
	STK_PARAM_INT    iPausedState  // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**         
**   ( .  akmGetParamIntDescr()  akmGetAllParamMeas())
**
** 'arrParamIntDescr' contains description of param's properties. Fields and
**   values are defined in 'akm_defs.h' header
** returns:
**   number of doubles copied to 'arrParamIntDescr'
*/
STK_FUNC_STRING akmGetParamName(
	STK_PARAM_INT  iParamID  // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**    
**
** returns:
**     
*/
STK_FUNC_STRING akmGetParamDescription(
	STK_PARAM_STRING sParamName  // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**    (,   )
**
** 'arrParamIntDescr' contains description of param's properties. Fields and
**   values are defined in 'akm_defs.h' header
** returns:
**   number of doubles copied to 'arrParamIntDescr'
*/
STK_FUNC_INT akmGetParamIntDescr(
	STK_PARAM_STRING sParamName,                                  // IN
	STK_PARAM_INT    arrParamIntDescr[PARAM_INTDESCR_ARRAY_SIZE]  // OUT
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**   e (,    float)
**
** 'arrParamFloatDescr' contains description of param's properties. Fields and
**   values are defined in 'akm_defs.h' header
** returns:
**   number of doubles copied to 'arrParamFloatDescr'
*/
STK_FUNC_INT akmGetParamFloatDescr(
	STK_PARAM_STRING sParamName,                                      // IN
	STK_PARAM_FLOAT  arrParamFloatDescr[PARAM_FLOATDESCR_ARRAY_SIZE]  // OUT
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**    ( float)
**
** returns:
**   number of doubles copied to 'arrParamData'
*/
STK_FUNC_INT akmGetParamDataFloat(
	STK_PARAM_STRING sParamName,                             // IN
	STK_PARAM_FLOAT  arrParamData[MAX_PARAMDATA_ARRAY_SIZE]  // OUT
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**    ( string)
**
** returns:
**   string data of the param specified
*/
STK_FUNC_STRING akmGetParamDataString(
	STK_PARAM_STRING sParamName // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**    ( float)
**
** returns:
**   0  fail to set data
**   1  data was changed ok
*/
STK_FUNC_INT akmSetParamDataFloat(
	STK_PARAM_STRING sParamName,                              // IN
	STK_PARAM_FLOAT  arrParamData[MAX_PARAMDATA_ARRAY_SIZE],  // IN
	STK_PARAM_INT    iArraySize                               // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**    ( float, 
**    .     )
**
** returns:
**   0  fail to set data
**   1  data was changed ok
*/
STK_FUNC_INT akmSetParamDataFloatPart(
	STK_PARAM_STRING sParamName,                              // IN
	STK_PARAM_INT    iRowStart,                               // IN
	STK_PARAM_INT    iRowEnd,                                 // IN
	STK_PARAM_INT    iColStart,                               // IN
	STK_PARAM_INT    iColEnd,                                 // IN
	STK_PARAM_FLOAT  arrParamData[MAX_PARAMDATA_ARRAY_SIZE],  // IN
	STK_PARAM_INT    iArraySize                               // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**    ( string)
**
** returns:
**   0  fail to set data
**   1  data was changed ok
*/
STK_FUNC_INT akmSetParamDataString(
	STK_PARAM_STRING sParamName,  // IN
	STK_PARAM_STRING sData        // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**    ( string,     )
**
** returns:
**   0  fail to set data
**   1  data was changed ok
*/
STK_FUNC_INT akmSetParamDataStringByte(
	STK_PARAM_STRING sParamName,                                // IN
	STK_PARAM_INT    arrStringBytes[MAX_PARAMDATA_ARRAY_SIZE],  // IN
	STK_PARAM_INT    iArraySize                                 // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**     
**
** 'iDirectCtrlState' specifies state of direct-control to be set. Values are
**   defined in 'akm_defs.h' header
** returns:
**   current state of DirectCtrl
*/
STK_FUNC_INT akmGetParamDirectCtrl(
	STK_PARAM_STRING sParamName  // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**     
**
** 'iDirectCtrlState' specifies state of direct-control to be set. Values are
**   defined in 'akm_defs.h' header
** returns:
**   0  fail to send request to change DirectCtrl state to AKM
**   1  request to change DirectCtrl state was sent to AKM
*/
STK_FUNC_INT akmSetParamDirectCtrl(
	STK_PARAM_STRING sParamName,       // IN
	STK_PARAM_INT    iDirectCtrlState  // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**    .    
**    ,    .
**
** 'iMeasType' specifies type of measurement. Values are
**   defined in 'akm_defs.h' header
** 'iMeasParam' specifies parameter of measurement. In case of polling
**   specifies period of polling. In case of data-src event specifies 
**   index of raster (protocol dependent).
** 'iMeasParam2' specifies additional parameter of measurement. In case
**   of data-src event specifies prescaler for raster.
** returns:
**   0  fail to change meas for parameter
**   1  meas for parameter changed OK
*/
STK_FUNC_INT akmSetParamMeasType(
	STK_PARAM_STRING sParamName,  // IN
	STK_PARAM_INT    iMeasType,   // IN
	STK_PARAM_INT    iMeasParam,  // IN
	STK_PARAM_INT    iMeasParam2  // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**     ,  
**       .
**
** returns:
**   number of param ID to 'arrParamMeas'
*/
STK_FUNC_INT akmGetAllParamMeas(
	STK_PARAM_STRING sModelName,                         // IN
	STK_PARAM_INT    arrParamMeas[MAX_PARAM_MEAS_COUNT]  // OUT
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**       .
**        akmGetAllParamMeas()
**
**  'arrParamMeasDef'    akmSetParamMeasType(),
**      'akm_defs.h'
** returns:
**   0  fail to get meas definition for parameter
**   1  meas definition for parameter got OK
*/
STK_FUNC_INT akmGetParamMeasDef(
	STK_PARAM_STRING sParamName,                           // IN
	STK_PARAM_INT    arrParamMeasDef[MEASDEF_FIELD_COUNT]  // OUT
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**       usb-.
**
**  'arrUserInfo'   'akm_defs.h'
** returns:
**    
*/
STK_FUNC_STRING akmGetUsbKeyInfo(
	STK_PARAM_INT  arrUserInfo[KEYINFO_FIELD_COUNT]  // OUT
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);


/*
**     ListCtrl
**
** 'iniFile'   ini-,   ,  
**       (    exe-)
** returns:
**   handle       (  
**              )
**   0(null)     
*/
STK_FUNC_INT akmCreateWindowListCtrl(
	STK_PARAM_STRING iniFile // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**     ListCtrl     
**      .     ini-,
**       (. akmCreateWindowListCtrl())
**
** 'wnd' - handle ,   akmCreateWindowListCtrl()
** 'column' -  
** returns:
**   ,      
*/
STK_FUNC_STRING akmGetWindowSelection(
	STK_PARAM_INT    wnd,    // IN
	STK_PARAM_STRING column  // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**     ( ,   ..)
**
** 'wnd' - handle ,   akmCreateWindowListCtrl()
** 'action' -    (. 'akm_defs.h')
** returns:
**   0 -    
**   1 -   
*/
STK_FUNC_INT akmPerformWindowAction(
	STK_PARAM_INT wnd,    // IN
	STK_PARAM_INT action  // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);


/*
**    ECU     
**
** 'service' -    
** 'arrData' - .    
** returns:
**   -1  -   
**   >=0 - -     'arrResult'
*/
STK_FUNC_INT akmDataSrcPerformService(
	STK_PARAM_STRING sModelName,                      // IN
	STK_PARAM_INT    service,                         // IN
	STK_PARAM_INT    arrData[MAX_SERVICE_DATA_SIZE],  // IN
	STK_PARAM_INT    sizeData,                        // IN
	STK_PARAM_INT    arrResult[MAX_SERVICE_DATA_SIZE] // OUT
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**    ECU ( . 'akm_defs.h')
**     
**
** 'function' -    
** returns:
**   0 -   
**   1 -   
*/
STK_FUNC_INT akmDataSrcPerformFunction(
	STK_PARAM_STRING sModelName,  // IN
	STK_PARAM_INT    function     // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**    KWP ( . 'akm_defs.h')
**   KWP- .    
**     .
**
** 'kwpCommand' - KWP- ( . 'akm_defs.h')
** 'arrCmdParams' -  
** 'cmdCount' -    'arrCmdParams'
** 'timeout' -  ( )   
** returns:
**  -2 - KWP-  
**  -1 -   
**   >=0 - -     'arrResult'
*/
STK_FUNC_INT akmDataSrcPerformKwpCommand(
	STK_PARAM_STRING sModelName,  // IN
	STK_PARAM_INT    kwpCommand,  // IN
	STK_PARAM_INT    arrCmdParams[MAX_SERVICE_DATA_SIZE],  // IN
	STK_PARAM_INT    cmdCount,                             // IN
	STK_PARAM_INT    timeout,                              // IN
	STK_PARAM_INT    arrResult[MAX_SERVICE_DATA_SIZE]      // OUT
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**     ECU
**
** 'dataAddress' -    (   )
** 'dataSize' -    
** returns:
**   0 -   
**   1 -   
*/
STK_FUNC_INT akmDataSrcReadData(
	STK_PARAM_STRING sModelName,                     // IN
	STK_PARAM_INT    dataAddress,                    // IN
	STK_PARAM_INT    dataSize,                       // IN
	STK_PARAM_INT    arrData[MAX_SERVICE_DATA_SIZE]  // OUT
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**     ECU
**
** 'dataAddress' -    (   )
** 'dataSize' -    
** returns:
**   0 -   
**   1 -   
*/
STK_FUNC_INT akmDataSrcWriteData(
	STK_PARAM_STRING sModelName,                     // IN
	STK_PARAM_INT    dataAddress,                    // IN
	STK_PARAM_INT    dataSize,                       // IN
	STK_PARAM_INT    arrData[MAX_SERVICE_DATA_SIZE]  // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**    (.HEX ) 
**
** 'sModelName' -  
** returns:
**    
*/
STK_FUNC_INT akmGetHexCount(
	STK_PARAM_STRING sModelName // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**      [0 .. akmGetHexCount()[
**
** 'sModelName' -  
** 'indexOfHex' -   (0 <= indexOfHex < akmGetHexCount())
** returns:
**    ,      
**    ,   
*/
STK_FUNC_STRING akmGetHexName(
	STK_PARAM_STRING sModelName, // IN
	STK_PARAM_INT    indexOfHex  // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**       
**
** 'sModelName' -  
** returns:
**         
*/
STK_FUNC_INT akmGetSegmentCount(
	STK_PARAM_STRING sModelName // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**      [0 .. akmGetSegmentCount()[
**
** 'sModelName' -  
** 'indexOfSegment' -   (0 <= indexOfSegment < akmGetSegmentCount())
** returns:
**    ,      
**    ,   
*/
STK_FUNC_STRING akmGetSegmentName(
	STK_PARAM_STRING sModelName,    // IN
	STK_PARAM_INT    indexOfSegment // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**      
**
** 'sModelName' -  
** returns:
**      
*/
STK_FUNC_STRING akmGetCurrentSegmentName(
	STK_PARAM_STRING sModelName    // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**     (.SDA ) 
**
** 'sModelName' -  
** returns:
**       
*/
STK_FUNC_INT akmGetDatasetCount(
	STK_PARAM_STRING sModelName // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**       [0 .. akmGetDatasetCount()[
**
** 'sModelName' -  
** 'indexOfDataset' -    (0 <= indexOfDataset < akmGetDatasetCount())
** returns:
**    ,       
**    ,   
*/
STK_FUNC_STRING akmGetDatasetName(
	STK_PARAM_STRING sModelName,    // IN
	STK_PARAM_INT    indexOfDataset // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**       
**
** 'sModelName' -  
** returns:
**      
*/
STK_FUNC_STRING akmGetActiveDatasetName(
	STK_PARAM_STRING sModelName    // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**       
**
** 'sModelName' -  
** 'sDatasetName' -  ,  
** 'isSyncWithEcu' -  == 1,     ECU 
**                      
** returns:
**   0 -     
**   1 -   
*/
STK_FUNC_INT akmSetActiveDatasetName(
	STK_PARAM_STRING sModelName,   // IN
	STK_PARAM_STRING sDatasetName, // IN
	STK_PARAM_INT    isSyncWithEcu // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**         
**
** 'sModelName' -  
** 'sSegmentName' -    
** 'sDatasetName' -    
** 'iCheckSynchro' - =1,       
**                      
** 'iShowProgress' - =1,      
** returns:
**   0 -   
**   1 -  
*/
STK_FUNC_INT akmWriteDatasetToEcu(
	STK_PARAM_STRING sModelName,    // IN
	STK_PARAM_STRING sSegmentName,  // IN
	STK_PARAM_STRING sDatasetName,  // IN
	STK_PARAM_INT    iCheckSynchro, // IN
	STK_PARAM_INT    iShowProgress  // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**         .
**      .
**
** 'sModelName' -  
** 'sSegmentName' -    
** 'sDatasetName' -    
** 'isUseSmartInit' - =1,       ( PRG
**                                )
** 'isUseKwpReset' - =1,     bootstrap,  
**                           reset   ,   
**                           KWP- (   )
** 'isFastInit' - =1,     DTR    
**                  bootstrap- 
** 'isSilentMode' - =0,      
** 'isAskForEcuReset' - =LOADER_RESET_MODE_CHECK(1),   ,  RESET ,
**                                LOADER_EXEC_NEED_RESET
**                      =LOADER_RESET_MODE_SKIP(2),   ,  RESET ,
**                             ,   RESET   
**                            
**                      =LOADER_RESET_MODE_NORMAL(3),     RESET
**                           
**                      (  . 'akm_defs.h')
** returns:
**   LOADER_EXEC_NEED_RESET (-1) -     RESET 
**   0 -   
**   1 -  
*/
STK_FUNC_INT akmWriteDatasetToEcuEx(
	STK_PARAM_STRING sModelName,          // IN
	STK_PARAM_STRING sSegmentName,        // IN
	STK_PARAM_STRING sDatasetName,        // IN
	STK_PARAM_INT    isUseSmartInit,      // IN
	STK_PARAM_INT    isUseKwpReset,       // IN
	STK_PARAM_INT    isFastInit,          // IN
	STK_PARAM_INT    isSilentMode,        // IN
	STK_PARAM_INT    iAskForEcuResetMode  // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);


/*
**   HEX     .  
**      .       
**  hardware reset- .
**
** 'sModelName' -  
** 'sHexName' -  ,   akmGetHexName()
** returns:
**   0 -   
**   1 -  
*/
STK_FUNC_INT akmWriteHexToEcu(
	STK_PARAM_STRING sModelName,  // IN
	STK_PARAM_STRING sHexName     // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**   HEX     .  
**     .
**
** 'sModelName' -  
** 'sHexName' -  ,   akmGetHexName()
**
**    akmWriteDatasetToEcuEx()
**
** returns:
**   LOADER_EXEC_NEED_RESET (-1) -     RESET 
**   0 -   
**   1 -  
*/
STK_FUNC_INT akmWriteHexToEcuEx(
	STK_PARAM_STRING sModelName,          // IN
	STK_PARAM_STRING sHexName,            // IN
	STK_PARAM_INT    isUseSmartInit,      // IN
	STK_PARAM_INT    isUseKwpReset,       // IN
	STK_PARAM_INT    isFastInit,          // IN
	STK_PARAM_INT    isSilentMode,        // IN
	STK_PARAM_INT    iAskForEcuResetMode  // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**   HEX     .  
**     .
**
** 'sModelName' -  
** 'sPreData1' -   "RELOAD.BIN"-
** 'sPreData2' -   "LOAD_2.BIN"-
** 'sHexName' -  .mod-,     (. 'akm_defs.h')
** 'iOffset' -   
** 'isSilentMode' - =0,      
** 'isAskForEcuReset' - =LOADER_RESET_MODE_CHECK(1),   ,  RESET ,
**                                LOADER_EXEC_NEED_RESET
**                      =LOADER_RESET_MODE_SKIP(2),   ,  RESET ,
**                             ,   RESET   
**                            
**                      =LOADER_RESET_MODE_NORMAL(3),     RESET
**                           
**                      (  . 'akm_defs.h')
** returns:
**   LOADER_EXEC_NEED_RESET (-1) -     RESET 
**   LOADER_EXEC_HEX_FAILED (-2) -   .hex-  
**   0 -   
**   1 -  
*/
STK_FUNC_INT akmWriteHexToEcu2(
	STK_PARAM_STRING sModelName,          // IN
	STK_PARAM_STRING sPreData1,           // IN
	STK_PARAM_STRING sPreData2,           // IN
	STK_PARAM_STRING sHexName,            // IN
	STK_PARAM_INT    iOffset,             // IN
	STK_PARAM_INT    isSilentMode,        // IN
	STK_PARAM_INT    iAskForEcuResetMode  // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);


/*
**     .   , ..
**       persistent-.
**     1.
**      'akm_defs.h'  MAX_MODEL_COUNT
**
** returns:
**      
*/
STK_FUNC_INT akmGetAllModels(
	STK_PARAM_INT  arrModelIndexes[MAX_MODEL_COUNT]  // OUT
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**      
**
** returns:
**     
*/
STK_FUNC_INT akmSetActiveModel(
	STK_PARAM_INT  modelIndex  // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**   () .    
**  persistent-
**
** returns:
**    () 
*/
STK_FUNC_STRING akmGetModelName(
	STK_PARAM_INT  modelIndex  // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**       .
**
** returns:
**    
*/
STK_FUNC_INT akmGetModelIndex(
	STK_PARAM_STRING  modelName  // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**     . 
**      'startAddress'   'wholeSize' ,  
**         .  , 
**     .
**
** 'isUseSmartInit' - =1,       ( PRG
**                                )
** 'isUseKwpReset' - =1,     bootstrap,  
**                           reset   ,   
**                           KWP- (   )
** 'isFastInit' - =1,     DTR    
**                  bootstrap- 
** 'isSilentMode' - =0,      
** 'isAskForEcuReset' - =LOADER_RESET_MODE_CHECK(1),   ,  RESET ,
**                                LOADER_EXEC_NEED_RESET
**                      =LOADER_RESET_MODE_SKIP(2),   ,  RESET ,
**                             ,   RESET   
**                            
**                      =LOADER_RESET_MODE_NORMAL(3),     RESET
**                           
**                      (  . 'akm_defs.h')
** returns:
**   1..3 -      
**   10..10+akmGetHexCount() -   hex-  ,  hex- 
**                               akmGetHexName(result-10)
**   LOADER_EXEC_NEED_RESET (-1) -     RESET 
**   LOADER_EXEC_HEX_FAILED (-2) -    FLASH
**   0 -    
*/
STK_FUNC_INT akmCheckHexInEcu(
	STK_PARAM_STRING  modelName,           // IN
	STK_PARAM_INT     startAddress,        // IN
	STK_PARAM_INT     wholeSize,           // IN
	STK_PARAM_STRING  stringToFind1,       // IN
	STK_PARAM_STRING  stringToFind2,       // IN
	STK_PARAM_STRING  stringToFind3,       // IN
	STK_PARAM_INT     isUseSmartInit,      // IN
	STK_PARAM_INT     isUseKwpReset,       // IN
	STK_PARAM_INT     isFastInit,          // IN
	STK_PARAM_INT     isSilentMode,        // IN
	STK_PARAM_INT     iAskForEcuResetMode  // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);

/*
**      . 
**      'startAddress',    
**      .  'wholeSize'  
**    ,  =0,    
**  .
**    akmCheckHexInEcu()
**
** returns:
**   10..10+akmGetDatasetCount() -     ,  
**                                    akmGetDatasetName(result-10)
**   LOADER_EXEC_NEED_RESET (-1) -     RESET 
**   LOADER_EXEC_HEX_FAILED (-2) -    FLASH
**   0 -    
*/
STK_FUNC_INT akmCheckTableDataInEcu(
	STK_PARAM_STRING  modelName,           // IN
	STK_PARAM_INT     startAddress,        // IN
	STK_PARAM_INT     wholeSize,           // IN
	STK_PARAM_INT     isUseSmartInit,      // IN
	STK_PARAM_INT     isUseKwpReset,       // IN
	STK_PARAM_INT     isFastInit,          // IN
	STK_PARAM_INT     isSilentMode,        // IN
	STK_PARAM_INT     iAskForEcuResetMode  // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);


/*
**     
**
** 'sModelName' -  
** 'partToSave' -     ,   
**                "" (  . 'akm_defs.h')
** returns:
**   0 -   
**   1 -  
*/
STK_FUNC_INT akmSaveProjectPart(
	STK_PARAM_STRING sModelName, // IN
	STK_PARAM_INT    partToSave // IN
	STK_PLUGIN_EXEC_PARAM(iSrcLine, pStkPrj)
	);


/*===========================================[ PSEUDO/INLINE FUNCTIONS ]====*/
/*===========================================[ SPECIAL ]====================*/
#ifdef __cplusplus
	}  /* extern "C" { */
#endif

/*===========================================[ END REDEFINITION DEFENCE ]===*/

#endif /* PLG_AKM_H */

/** (END OF FILE  : plg_akm.h) **********************************************/
